/*
 *   m_svsmkick - /SVSMKICK removing all local users with a kicked.
 *   Must be sent through an U:Lined server
 *   (C) Copyright 2007 Diablo <diablo@unrealircd.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#ifdef STRIPBADWORDS
#include "badwords.h"
#endif
#ifdef _WIN32
#include "version.h"
#endif

DLLFUNC int m_svsmkick(aClient *cptr, aClient *sptr, int parc, char *parv[]);

/* Place includes here */
#define MSG_SVSMKICK "SVSMKICK"
#define TOK_SVSMKICK "MK"

ModuleHeader MOD_HEADER(m_svsmkick)
  = {
	"m_svsmkick",
    "$Id: m_svsmkick.c,v 1.0 2007/01/26 Diablo Exp $",	
	"removing all local users with a kicked", 
	"3.2-b8-1",
	NULL 
    };

DLLFUNC int MOD_INIT(m_svsmkick)(ModuleInfo *modinfo)
{
 	add_Command(MSG_SVSMKICK, TOK_SVSMKICK, m_svsmkick, MAXPARA);
 	return MOD_SUCCESS;
 }
 
 
DLLFUNC int MOD_LOAD(m_svsmkick)(int module_load)
{
 	return MOD_SUCCESS;
}
 
  
DLLFUNC int MOD_UNLOAD(m_svsmkick)(int module_unload)
{
 	if (del_Command(MSG_SVSMKICK, TOK_SVSMKICK, m_svsmkick) < 0)
 	{
 		sendto_realops("Failed to delete commands when unloading %s",
		MOD_HEADER(m_svsmkick).name);
 	}
 	return MOD_SUCCESS;
} 

/* m_svsmkick
 * parv[0] - sender prefix
 * parv[1] - channel
 * parv[2] - kick reason
*/

DLLFUNC int m_svsmkick(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
    aChannel *chptr = NULL;
    Member *curr = NULL, *next = NULL;
    
    if(!IsULine(sptr) || parc < 2) /* we can kick without a reason. */
       return 0;
       
    if(!(chptr = find_channel(parv[1], NULL)))
        return 0;
        
    curr = chptr->members;
     
    while(curr)
    {
        next = curr->next;
        if(MyClient(curr->cptr)) /* tell our clients that the channel is gone */
           sendto_prefix_one(curr->cptr, sptr, ":%s KICK %s %s :%s", parv[0],
           parv[1], curr->cptr->name, (parc == 3) ? parv[2] : "");
           remove_user_from_channel(curr->cptr, chptr);
           curr = next;
       }
       /* at this point, the channel should not exist locally */
       sendto_serv_butone(cptr, ":%s SVSMKICK %s :%s", parv[0], parv[1], 
           (parc == 3) ? parv[2] : "");
    return 0;
}
